<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>Dialog</name>
    <message>
        <location filename="../Dialog.ui" line="+94"/>
        <source>OK</source>
        <translatorcomment>--exact match--
--file: qvfb_pl.ts--
OK
&amp;OK</translatorcomment>
        <translation>OK</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Cancel</source>
        <translatorcomment>--exact match--
--file: qvfb_pl.ts--
Anuluj
&amp;Anuluj</translatorcomment>
        <translation>Anuluj</translation>
    </message>
</context>
<context>
    <name>Widgets</name>
    <message>
        <location filename="../Widgets.js" line="+56"/>
        <source>&amp;Widgets</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>&amp;Widżety</translation>
    </message>
</context>
</TS>
